@@ -1,7 +1,7 @@
 package App::CSelUtils;
 
-our $DATE = '2016-03-13'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2016-03-20'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 
 our %SPEC;
 
-$SPEC{parse_csel_expr} = {
+$SPEC{parse_csel} = {
     v => 1.1,
     summary => 'Parse CSel expression',
     args => {
@@ -21,10 +21,10 @@ $SPEC{parse_csel_expr} = {
     },
     'cmdline.default_format' => 'json-pretty',
 };
-sub parse_csel_expr {
-    require Data::CSel::Parser;
+sub parse_csel {
+    require Data::CSel;
     my %args = @_;
-    [200, "OK", Data::CSel::Parser::parse_csel_expr($args{expr})];
+    [200, "OK", Data::CSel::parse_csel($args{expr})];
 }
 
 1;
@@ -43,7 +43,7 @@ App::CSelUtils - Utilities related to Data::CSel
 
 =head1 VERSION
 
-This document describes version 0.01 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2016-03-13.
+This document describes version 0.02 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2016-03-20.
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ This distribution contains the following utilities:
 =head1 FUNCTIONS
 
 
-=head2 parse_csel_expr(%args) -> [status, msg, result, meta]
+=head2 parse_csel(%args) -> [status, msg, result, meta]
 
 Parse CSel expression.
 
